Converts a numeric literal into a Num type, generating a compile-time error if the literal is out of range for the type.
In comparison to num!, this macro also accepts literals that can only be approximately represented by the type.
MinMax derive macro.
for each method,
the derive implementation maps each field using the method.
Throws a compile-time error for enums unless you use the flat_minmax attribute.
Signed derive macro.
Signed is a trait with methods that check sign attributes.
This macro expects the type to only have one field,
and redirects the trait methods to the field as Signed.
Whole derive macro.
Whole is a trait that has no methods and is used to mark types as always round.
This derive macro doesn’t verify anything about the data in the type,
so make sure the type should be Whole when using this derive macro.